---
name: Bug report
about: Create a report to help us improve
title: ''
labels: ''
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior:
1. Downloads data '...'
2. Run '...' with flags '...'
3. Scroll up on the log to '....'
4. See error

**Expected behavior**
A clear and concise description of what you expected to happen.

**Screenshots and charts**
If applicable, add screenshots and charts to help explain your problem.

**Desktop (please complete the following information):**
 - OS: [e.g. Mac]
 - Version [e.g. 22]
 - Compiler [e.g gcc]
 - Flags [e.g O2]
 - Other relevant hardware specs [e.g. Dual-core]
 - Build system [e.g. Makefile]

**Additional context**
Add any other context about the problem here.
